@@ -1,21 +1,18 @@
-#--
-# Copyright 2006 Luke Kanies <luke@madstop.com>
+# Facter - Host Fact Detection and Reporting
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
+# Copyright 2011 Puppet Labs Inc
 #
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# http://www.apache.org/licenses/LICENSE-2.0
 #
-#--
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and 
+# limitations under the License.
 
 module Facter
     # This is just so the other classes have the constant.
@@ -27,7 +24,7 @@ module Facter
     include Comparable
     include Enumerable
 
-    FACTERVERSION = '1.5.9'
+    FACTERVERSION = '1.6.1'
     # = Facter
     # Functions as a hash of 'facts' you might care about about your
     # system, such as mac address, IP address, Video card, etc.
@@ -49,6 +46,7 @@ module Facter
     RESET = "[0m"
     @@debug = 0
     @@timing = 0
+    @@messages = {}
 
     # module methods
 
@@ -161,6 +159,12 @@ module Facter
         Facter.reset
     end
 
+    # Clear all messages. Used only in testing. Can't add to self.clear
+    # because we don't want to warn multiple times for items that are warnonce'd
+    def self.clear_messages
+        @@messages.clear
+    end
+
     # Set debugging on or off.
     def self.debugging(bit)
         if bit
@@ -211,6 +215,14 @@ module Facter
         end
     end
 
+    # Warn once.
+    def self.warnonce(msg)
+        if msg and not msg.empty? and @@messages[msg].nil?
+            @@messages[msg] = true
+            Kernel.warn(msg)
+        end
+    end
+
     # Remove them all.
     def self.reset
         @collection = nil
