@@ -1,3 +1,16 @@
+# Fact: manufacturer
+#
+# Purpose: Return the hardware manufacturer information about the hardware.
+#
+# Resolution:
+#   On OpenBSD, queries sysctl values, via a util class.
+#   On SunOS Sparc, uses prtdiag via a util class.
+#   On Windows, queries the system via a util class.
+#   Uses the 'util/manufacturer.rb' for fallback parsing.
+#
+# Caveats:
+#
+
 # manufacturer.rb
 # Facts related to hardware manufacturer
 #
@@ -12,6 +25,11 @@ if Facter.value(:kernel) == "OpenBSD"
         'hw.serialno' => 'serialnumber'
     }
 
+    Facter::Manufacturer.sysctl_find_system_info(mfg_keys)
+elsif Facter.value(:kernel) == "Darwin" 
+    mfg_keys = {
+        'hw.model'   => 'productname'
+    }
     Facter::Manufacturer.sysctl_find_system_info(mfg_keys)
 elsif Facter.value(:kernel) == "SunOS" and Facter.value(:hardwareisa) == "sparc"
     Facter::Manufacturer.prtdiag_sparc_find_system_info()
