@@ -1,3 +1,16 @@
+# Fact: operatingsystem
+#
+# Purpose: Return the name of the operating system.
+#
+# Resolution:
+#   If the kernel is a Linux kernel, check for the existence of a selection of
+#   files in /etc/ to find the specific flavour.
+#   On SunOS based kernels, return Solaris.
+#   On systems other than Linux, use the kernel value.
+#
+# Caveats:
+#
+
 require 'facter/lsb'
 
 Facter.add(:operatingsystem) do
@@ -24,6 +37,8 @@ Facter.add(:operatingsystem) do
             "MeeGo"
         elsif FileTest.exists?("/etc/arch-release")
             "Archlinux"
+        elsif FileTest.exists?("/etc/oracle-release")
+            "OracleLinux"
         elsif FileTest.exists?("/etc/enterprise-release")
             if FileTest.exists?("/etc/ovs-release")
                 "OVS"
@@ -38,6 +53,8 @@ Facter.add(:operatingsystem) do
             txt = File.read("/etc/redhat-release")
             if txt =~ /centos/i
                 "CentOS"
+            elsif txt =~ /CERN/
+                "SLC"
             elsif txt =~ /scientific/i 
                 "Scientific"
             else
@@ -60,6 +77,8 @@ Facter.add(:operatingsystem) do
             "Slamd64"
         elsif FileTest.exists?("/etc/slackware-version")
             "Slackware"
+        elsif FileTest.exists?("/etc/alpine-release")
+            "Alpine"
         end
     end
 end
