@@ -1,13 +1,32 @@
+# Fact: operatingsystemrelease
+#
+# Purpose: Returns the release of the operating system.
+#
+# Resolution:
+#   On RedHat derivatives, returns their '/etc/<variant>-release' file.
+#   On Debian, returns '/etc/debian_version'.
+#   On Ubuntu, parses '/etc/issue' for the release version.
+#   On Suse, derivatives, parses '/etc/SuSE-release' for a selection of version
+#   information.
+#   On Slackware, parses '/etc/slackware-version'.
+#   
+#   On all remaining systems, returns the 'kernelrelease' value.
+#
+# Caveats:
+#
+
 Facter.add(:operatingsystemrelease) do
-    confine :operatingsystem => %w{CentOS Fedora oel ovs RedHat MeeGo}
+    confine :operatingsystem => %w{CentOS Fedora oel ovs OracleLinux RedHat MeeGo Scientific SLC}
     setcode do
         case Facter.value(:operatingsystem)
-        when "CentOS", "RedHat"
+        when "CentOS", "RedHat", "Scientific", "SLC"
             releasefile = "/etc/redhat-release"
         when "Fedora"
             releasefile = "/etc/fedora-release"
         when "MeeGo"
             releasefile = "/etc/meego-release"
+        when "OracleLinux"
+            releasefile = "/etc/oracle-release"
         when "OEL", "oel"
             releasefile = "/etc/enterprise-release"
         when "OVS", "ovs"
@@ -105,6 +124,13 @@ Facter.add(:operatingsystemrelease) do
     end
 end
 
+Facter.add(:operatingsystemrelease) do
+  confine :operatingsystem => :Alpine
+  setcode do
+    File.read('/etc/alpine-release')
+  end
+end
+
 Facter.add(:operatingsystemrelease) do
     setcode do Facter[:kernelrelease].value end
 end
