@@ -4,16 +4,14 @@
 # confinements specified must all be true for the resolution to be
 # suitable.
 require 'facter/util/confine'
+require 'facter/util/config'
 
 require 'timeout'
-require 'rbconfig'
 
 class Facter::Util::Resolution
     attr_accessor :interpreter, :code, :name, :timeout
 
-    WINDOWS = Config::CONFIG['host_os'] =~ /mswin|win32|dos|mingw|cygwin/i
-
-    INTERPRETER = WINDOWS ? 'cmd.exe' : '/bin/sh'
+    INTERPRETER = Facter::Util::Config.is_windows? ? "cmd.exe" : "/bin/sh"
 
     def self.have_which
         if ! defined?(@have_which) or @have_which.nil?
@@ -32,8 +30,8 @@ class Facter::Util::Resolution
     # Returns nil if the program can't be found, or if there is a problem
     # executing the code.
     #
-    def self.exec(code, interpreter = INTERPRETER)
-        raise ArgumentError, "invalid interpreter" unless interpreter == INTERPRETER
+    def self.exec(code, interpreter = nil)
+        Facter.warnonce "The interpreter parameter to 'exec' is deprecated and will be removed in a future version." if interpreter
 
         # Try to guess whether the specified code can be executed by looking at the
         # first word. If it cannot be found on the PATH defer on resolving the fact
@@ -45,7 +43,7 @@ class Facter::Util::Resolution
         # Windows' %x{} throws Errno::ENOENT when the command is not found, so we 
         # can skip the check there. This is good, since builtins cannot be found 
         # elsewhere.
-        if have_which and !WINDOWS
+        if have_which and !Facter::Util::Config.is_windows?
             path = nil
             binary = code.split.first
             if code =~ /^\//
@@ -85,17 +83,26 @@ class Facter::Util::Resolution
         end
     end
 
+    def has_weight(weight)
+        @weight = weight
+    end
+
     # Create a new resolution mechanism.
     def initialize(name)
         @name = name
         @confines = []
         @value = nil
         @timeout = 0
+        @weight = nil
     end
 
-    # Return the number of confines.
-    def length
-        @confines.length
+    # Return the importance of this resolution.
+    def weight
+        if @weight
+            @weight
+        else
+            @confines.length
+        end
     end
 
     # We need this as a getter for 'timeout', because some versions
@@ -107,6 +114,7 @@ class Facter::Util::Resolution
 
     # Set our code for returning a value.
     def setcode(string = nil, interp = nil, &block)
+        Facter.warnonce "The interpreter parameter to 'setcode' is deprecated and will be removed in a future version." if interp
         if string
             @code = string
             @interpreter = interp || INTERPRETER
@@ -118,6 +126,16 @@ class Facter::Util::Resolution
         end
     end
 
+    def interpreter
+      Facter.warnonce "The 'Facter::Util::Resolution.interpreter' method is deprecated and will be removed in a future version."
+      @interpreter
+    end
+
+    def interpreter=(interp)
+      Facter.warnonce "The 'Facter::Util::Resolution.interpreter=' method is deprecated and will be removed in a future version."
+      @interpreter = interp
+    end
+
     # Is this resolution mechanism suitable on the system in question?
     def suitable?
         unless defined? @suitable
@@ -134,7 +152,7 @@ class Facter::Util::Resolution
     # How we get a value for our resolution mechanism.
     def value
         result = nil
-        return result if @code == nil and @interpreter == nil
+        return result if @code == nil
 
         starttime = Time.now.to_f
 
@@ -143,7 +161,7 @@ class Facter::Util::Resolution
                 if @code.is_a?(Proc)
                     result = @code.call()
                 else
-                    result = Facter::Util::Resolution.exec(@code,@interpreter)
+                    result = Facter::Util::Resolution.exec(@code)
                 end
             end
         rescue Timeout::Error => detail
