@@ -37,4 +37,15 @@ describe "Physical processor count facts" do
 
         Facter.fact(:physicalprocessorcount).value.should == 4
     end
+
+    it "should return 4 physical CPUs on Windows" do
+        Facter.fact(:kernel).stubs(:value).returns("windows")
+
+        require 'facter/util/wmi'
+        ole = stub 'WIN32OLE'
+        Facter::Util::WMI.expects(:execquery).with("select Name from Win32_Processor").returns(ole)
+        ole.stubs(:Count).returns(4)
+
+        Facter.fact(:physicalprocessorcount).value.should == 4
+    end
 end
